<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Spline</name>
    <message>
        <location filename="../Spline.js" line="+72"/>
        <source>Spline Tools</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Narzędzia splajów</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show spline tools</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Wyświetla narzędzia splajnów</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Spline</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
&amp;Krzywa składana
Krzywe &amp;składane</translatorcomment>
        <translation>&amp;Splajn</translation>
    </message>
</context>
</TS>
